@@ -1,10 +1,10 @@
 """
 The inventory module defines the ``Inventory`` class. Each ``Inventory`` instance contains one or
-multiple radionuclides, each with an associated activity. The decay of the radionuclide(s) in an
-``Inventory`` can be calculated by using the ``decay()`` method (normal double precision
-arithmetic). Use the ``decay_high_precision()`` method for a SymPy high numerical precision
-calculation. A ``DecayData`` dataset associated with each ``Inventory`` instance is the radioactive
-decay data source (default is rd.DEFAULTDATA).
+more radionuclides, each with an associated activity. The decay of the radionuclide(s) in an
+``Inventory`` can be calculated by using the ``decay()`` method (normal double-precision
+floating-point operations). Use the ``decay_high_precision()`` method to perform a SymPy high
+numerical precision calculation. A ``DecayData`` dataset associated with each ``Inventory``
+instance is the radioactive decay data source (default is rd.DEFAULTDATA).
 
 The code examples shown in the docstrings assume the ``radioactivedecay`` package has been imported
 as:
@@ -17,9 +17,11 @@ as:
 """
 
 from functools import singledispatch, update_wrapper
-from typing import Callable, Dict, List, Union
+from typing import Callable, Dict, List, Tuple, Union
+import matplotlib
 from sympy import exp, nsimplify
 from radioactivedecay.decaydata import DecayData, DEFAULTDATA, np
+from radioactivedecay.plots import _decay_graph
 from radioactivedecay.radionuclide import Radionuclide
 from radioactivedecay.utils import (
     parse_radionuclide,
@@ -28,6 +30,9 @@ from radioactivedecay.utils import (
 )
 
 
+# pylint: disable=too-many-arguments, too-many-locals
+
+
 def _add_dictionaries(
     dict_a: Dict[str, float], dict_b: Dict[str, float]
 ) -> Dict[str, float]:
@@ -67,6 +72,33 @@ def _add_dictionaries(
     return new_dict
 
 
+def _sort_dictionary_alphabetically(
+    input_inv_dict: Dict[str, float]
+) -> Dict[str, float]:
+    """
+    Sorts a dictionary alphabetically by its keys.
+
+    Parameters
+    ----------
+    input_inv_dict : dict
+        Dictionary containing radionuclide strings or Radionuclide objects as keys and activities
+        as values.
+
+    Returns
+    -------
+    dict
+        Inventory dictionary which has been sorted by the radionuclides alphabetically.
+
+    Examples
+    --------
+    >>> rd.inventory._sort_dictionary_alphabetically({'U-235': 1.2, 'Tc-99m': 2.3, 'Tc-99': 5.8})
+    {'Tc-99': 5.8, 'Tc-99m': 2.3, 'U-235': 1.2}
+
+    """
+
+    return dict(sorted(input_inv_dict.items(), key=lambda x: x[0]))
+
+
 def _check_dictionary(
     input_inv_dict: Dict[Union[str, Radionuclide], float],
     radionuclides: List[str],
@@ -124,6 +156,35 @@ def _check_dictionary(
     return inv_dict
 
 
+def _sort_list_according_to_dataset(
+    input_list: List[str], key_dict: Dict[str, int]
+) -> List[str]:
+    """
+    Sorts a list of radionuclides based on their order of appearence in the decay dataset.
+
+    Parameters
+    ----------
+    input_list : list
+        List of radionuclide strings to be sorted.
+    key_dict : dict
+        Dictionary from the decay dataset with radionuclide strings as keys and their position
+        (integers) in the decay dataset.
+
+    Returns
+    -------
+    list
+        Sorted radionuclide list.
+
+    Examples
+    --------
+    >>> rd.inventory._sort_list_according_to_dataset(['Tc-99', 'Tc-99m'], rd.DEFAULTDATA.radionuclide_dict)
+    ['Tc-99m', 'Tc-99']
+
+    """
+
+    return sorted(input_list, key=lambda radionuclide: key_dict[radionuclide])
+
+
 def _method_dispatch(func):
     """Adds singledispatch support for class methods."""
 
@@ -192,8 +253,8 @@ class Inventory:
         parsed_contents: Dict[str, float] = _check_dictionary(
             contents, data.radionuclides, data.dataset
         ) if check is True else contents
-        self.contents: Dict[str, float] = dict(
-            sorted(parsed_contents.items(), key=lambda x: x[0])
+        self.contents: Dict[str, float] = _sort_dictionary_alphabetically(
+            parsed_contents
         )
         self.data: DecayData = data
 
@@ -436,9 +497,9 @@ class Inventory:
             these time units.
         sig_fig: None or int, optional
             Performs a decay calculation using arbitrary-precision arithmetic with SymPy for this
-            many significant figures. For high precision calculations, recommended is 320. sig_fig
-            must be greater than 0. Default is None, which i standard SciPy/NumPy double precision
-            calculations.
+            many significant figures. For high precision calculations, recommended setting is 320.
+            sig_fig must be greater than 0. Default is None, which is standard SciPy/NumPy double
+            precision calculations.
 
         Returns
         -------
@@ -501,12 +562,15 @@ class Inventory:
         )
         vector_at = vector_nt[indices] * self.data.scipy_data.decay_consts[indices]
 
-        new_contents = dict(zip(self.data.radionuclides[indices], vector_at))
-        new_contents = dict(sorted(new_contents.items(), key=lambda x: x[0]))
+        new_contents = _sort_dictionary_alphabetically(
+            dict(zip(self.data.radionuclides[indices], vector_at))
+        )
 
         return Inventory(new_contents, False, self.data)
 
-    def decay_high_precision(self, decay_time: float, units: str = "s") -> "Inventory":
+    def decay_high_precision(
+        self, decay_time: float, units: str = "s", sig_fig: int = 320
+    ) -> "Inventory":
         """
         Decay calculation with high numerical precision. This uses SymPy arbitrary-precision
         arithmetic functions for the decay calculation. The results can be more accurate than
@@ -515,7 +579,8 @@ class Inventory:
         differ by many orders of magnitude.
 
         This function requires that the decay dataset associated with the Inventory instance
-        contains a SymPy version of the decay data. It uses sig_fig=320 for the SymPy calculation.
+        contains a SymPy version of the decay data. Default is sig_fig=320 for the SymPy
+        calculation.
 
         Parameters
         ----------
@@ -525,6 +590,8 @@ class Inventory:
             Units of decay_time (default is seconds). Options are 'ns', 'us', 'ms', 's', 'm', 'h',
             'd', 'y', 'ky', 'My', 'Gy', 'Ty', 'Py', and some of the common spelling variations of
             these time units.
+        sig_fig: int, optional
+            Number of significant figures for high precision decay calculation. Deafult is 320.
 
         Returns
         -------
@@ -546,7 +613,7 @@ class Inventory:
 
         """
 
-        return self.decay(decay_time, units, sig_fig=320)
+        return self.decay(decay_time, units, sig_fig)
 
     def _decay_sympy(self, decay_time: float, units: str, sig_fig: int) -> "Inventory":
         """
@@ -595,26 +662,27 @@ class Inventory:
             new_contents[self.data.radionuclides[i]] = float(
                 vector_nt[i, 0] * self.data.sympy_data.decay_consts[i, 0]
             )
-        new_contents = dict(sorted(new_contents.items(), key=lambda x: x[0]))
+        new_contents = _sort_dictionary_alphabetically(new_contents)
 
         return Inventory(new_contents, False, self.data)
 
-    def half_lives(self, units: str = "s") -> Dict[str, float]:
+    def half_lives(self, units: str = "s") -> Dict[str, Union[float, str]]:
         """
-        Returns dictionary of half-lives of the radionuclides in the Inventory in chosen time
-        units.
+        Returns dictionary of half-lives of the radionuclides in the Inventory in your chosen time
+        units, or as a human-readable string with appropriate units.
 
         Parameters
         ----------
         units : str, optional
-            Units for half-lives (default is 's', i.e. seconds). Options are 'ps', 'ns', 'us',
-            'ms', 's', 'm', 'h', 'd', 'y', 'ky', 'My', 'Gy', 'Ty', 'Py', and some of the common
-            spelling variations of these time units.
+            Units for half-life. Options are 'ps', 'ns', 'μs', 'us', 'ms', 's', 'm', 'h', 'd', 'y',
+            'ky', 'My', 'By', 'Gy', 'Ty', 'Py', and common spelling variations. Default is 's', i.e.
+            seconds. Use 'readable' to get strings of the half-lives in human-readable units.
 
         Returns
         -------
         dict
-            Dictionary with radionuclide strings as keys and half-life floats as values.
+            Dictionary with radionuclide strings as keys and half-life floats or human-readable
+            half-life strings as values.
 
         Examples
         --------
@@ -626,6 +694,13 @@ class Inventory:
 
         return {nuc: self.data.half_life(nuc, units) for nuc in self.contents}
 
+    def half_life(self, units: str = "s") -> Dict[str, Union[float, str]]:
+        """
+        Same behaviour as half_lives() method.
+        """
+
+        return self.half_lives(units)
+
     def progeny(self) -> Dict[str, List[str]]:
         """
         Returns dictionary with the direct progeny of the radionuclides in the Inventory.
@@ -695,6 +770,146 @@ class Inventory:
             nuc: Radionuclide(nuc, self.data).decay_modes() for nuc in self.contents
         }
 
+    def plot(
+        self,
+        xmax: float,
+        xunits: str = "s",
+        xmin: float = 0.0,
+        xscale: str = "linear",
+        yscale: str = "linear",
+        ymin: float = 0.0,
+        ymax: Union[None, float] = None,
+        yunits: Union[None, str] = None,
+        sig_fig: Union[None, int] = None,
+        display: Union[str, List[str]] = "all",
+        order: str = "dataset",
+        npoints: Union[None, int] = None,
+        fig: Union[None, matplotlib.figure.Figure] = None,
+        ax: Union[None, matplotlib.axes.Axes] = None,
+        **kwargs,
+    ) -> Tuple[matplotlib.figure.Figure, matplotlib.axes.Axes]:
+        """
+        Plots a decay graph showing the change in activity of the inventory over time. Creates
+        matplotlib fig, ax objects if they are not supplied. Returns fig, ax tuple.
+
+        Parameters
+        ----------
+        xmax : float
+            Maximum decay time on x-axis.
+        xunits : str, optional
+            Units for decay times (default is 's', i.e. seconds). Options are 'ps', 'ns', 'us',
+            'ms', 's', 'm', 'h', 'd', 'y', 'ky', 'My', 'Gy', 'Ty', 'Py', and some of the common
+            spelling variations of these time units.
+        xmin : float, optional
+            Minimum decay time on x-axis (default is 0.0 for linear x-axis, 0.1 for log x-axis).
+        xscale : str, optional
+            The time axis scale type to apply ('linear' or 'log', default is 'linear').
+        yscale : str, optional
+            The activities axis scale type to apply ('linear' or 'log', default is 'linear').
+        ymin : float, optional
+            Minimum activity for the y-axis (default is 0.0 for linear y-axis, 0.1 for log y-axis).
+        ymax : None or float, optional
+            Maximum activity for the y-axis. Default is None, which sets the limit to 1.05x the
+            maximum radioactivity that occurs over the decay period.
+        yunits : None or str, optional
+            Acivity unit for the y-axis label (default is to show no unit).
+        sig_fig : None or int, optional
+            None: use normal double precision decay calculations (default), int: perform Sympy high
+            precision decay calculations with this many significant figures.
+        display : str or list, optional
+            Only display the radionuclides within this list on the graph. Use this parameter when
+            you want to choose specific radionuclide decay curves shown on the graph, either by
+            supplying a string (to show one radionuclide) or a list of strings (to show multiple).
+            Default is 'all', which displays all radionuclides present upon decay of the inventory.
+        order : str, optional
+            Order to display the radionuclide decay curves on the graph if you do not specify the
+            order via the display parameter. Default order is by "dataset", which follows the order
+            of the radionuclides in the decay dataset (highest to lowest radionuclides in the decay
+            chains). Use "alphabetical" if you want the radionuclides to be ordered alphabetically.
+        npoints : None or int, optional
+            Number of time points used to plot graph (default is 501 for normal precision decay
+            calculations, or 51 for high precision decay calculations (sig_fig > 0)).
+        fig : None or matplotlib.figure.Figure, optional
+            matplotlib figure object to use, or None makes ``radioactivedecay`` create one (default
+            is None).
+        ax : None or matplotlib.axes.Axes, optional
+            matplotlib axes object to use, or None makes ``radioactivedecay`` create one (default
+            is None).
+        **kwargs, optional
+            All additional keyword arguments to supply to matplotlib plot() function.
+
+        Returns
+        -------
+        fig : matplotlib.figure.Figure
+            matplotlib figure object used to plot decay chain.
+        ax : matplotlib.axes.Axes
+            matplotlib axes object used to plot decay chain.
+
+        Raises
+        ------
+        ValueError
+            If the order parameter is invalid.
+
+        """
+
+        if npoints is None:
+            if sig_fig:
+                npoints = 51
+            else:
+                npoints = 501
+
+        if xscale == "linear":
+            time_points = np.linspace(xmin, xmax, num=npoints)
+        else:
+            if xmin == 0.0:
+                xmin = 0.1
+            time_points = np.logspace(np.log10(xmin), np.log10(xmax), num=npoints)
+
+        if display == "all":
+            if order == "dataset":
+                display = _sort_list_according_to_dataset(
+                    self.decay(0).radionuclides, self.data.radionuclide_dict
+                )
+            elif order == "alphabetical":
+                display = self.decay(0).radionuclides
+            else:
+                raise ValueError(
+                    str(order) + " is not a valid string for the order parameter."
+                )
+        else:
+            if isinstance(display, str):
+                display = [display]
+            display = [
+                parse_radionuclide(rad, self.data.radionuclides, self.data.dataset)
+                for rad in display
+            ]
+
+        acts = np.zeros(shape=(npoints, len(display)))
+        for i in range(0, npoints):
+            decayed_contents = self.decay(time_points[i], xunits, sig_fig).contents
+            acts[i] = [decayed_contents[rad] for rad in display]
+
+        if yscale == "log" and ymin == 0.0:
+            ymin = 0.1
+        ylimits = [ymin, ymax] if ymax else [ymin, 1.05 * acts.max()]
+
+        fig, ax = _decay_graph(
+            time_points=time_points,
+            activities=acts.T,
+            radionuclides=display,
+            xunits=xunits,
+            yunits=yunits,
+            xscale=xscale,
+            yscale=yscale,
+            ylimits=ylimits,
+            display=set(display),
+            fig_in=fig,
+            ax_in=ax,
+            **kwargs,
+        )
+
+        return fig, ax
+
     def __repr__(self) -> str:
         return (
             "Inventory: " + str(self.contents) + ", decay dataset: " + self.data.dataset
