@@ -4,13 +4,20 @@ Unit tests for inventory.py functions, classes and methods.
 
 import copy
 import unittest
-from radioactivedecay.inventory import _add_dictionaries, _check_dictionary, Inventory
+from unittest.mock import patch
+from radioactivedecay.inventory import (
+    _add_dictionaries,
+    _sort_dictionary_alphabetically,
+    _check_dictionary,
+    _sort_list_according_to_dataset,
+    Inventory,
+)
 from radioactivedecay import DEFAULTDATA, DecayData, Radionuclide
 
 
 class Test(unittest.TestCase):
     """
-    Unit tests for decayfunctions.py functions, classes and methods.
+    Unit tests for inventory.py functions, classes and methods.
     """
 
     # pylint: disable=too-many-public-methods
@@ -27,6 +34,17 @@ class Test(unittest.TestCase):
             {"Pm-141": 4.0, "Rb-78": 2.0, "Rb-90": 4.0},
         )
 
+    def test__sort_dictionary_alphabetically(self):
+        """
+        Test the sorting of a dictionary by its keys alphabetically.
+        """
+
+        inv_dict = {"U-235": 1.2, "Tc-99m": 2.3, "Tc-99": 5.8}
+        self.assertEqual(
+            _sort_dictionary_alphabetically(inv_dict),
+            {"Tc-99": 5.8, "Tc-99m": 2.3, "U-235": 1.2},
+        )
+
     def test__check_dictionary(self):
         """
         Test the checking of inventory dictionaries.
@@ -80,6 +98,19 @@ class Test(unittest.TestCase):
         with self.assertRaises(ValueError):
             _check_dictionary({"1.0": "H-3"}, radionuclides, dataset)
 
+    def test__sort_list_according_to_dataset(self):
+        """
+        Test the sorting of list of radionuclides according to their position in the decay dataset.
+        """
+
+        radionuclide_list = ["Tc-99", "Tc-99m"]
+        self.assertEqual(
+            _sort_list_according_to_dataset(
+                radionuclide_list, DEFAULTDATA.radionuclide_dict
+            ),
+            ["Tc-99m", "Tc-99"],
+        )
+
     def test_inventory_instantiation(self):
         """
         Test instantiation of Inventory objects.
@@ -402,6 +433,19 @@ class Test(unittest.TestCase):
 
         inv = Inventory({"C-14": 1.0, "H-3": 2.0})
         self.assertEqual(inv.half_lives("y"), {"C-14": 5700.0, "H-3": 12.32})
+        self.assertEqual(
+            inv.half_lives("readable"), {"C-14": "5.70 ky", "H-3": "12.32 y"}
+        )
+
+    def test_inventory_half_life(self):
+        """
+        Test spelling variation of half_lives() method.
+        """
+
+        inv = Inventory({"C-14": 1.0, "H-3": 2.0})
+        self.assertEqual(inv.half_life("s"), inv.half_lives("s"))
+        self.assertEqual(inv.half_life("y"), inv.half_lives("y"))
+        self.assertEqual(inv.half_life("readable"), inv.half_lives("readable"))
 
     def test_inventory_progeny(self):
         """
@@ -432,6 +476,49 @@ class Test(unittest.TestCase):
             {"C-14": ["\u03b2-"], "K-40": ["\u03b2-", "\u03b2+ \u0026 EC"]},
         )
 
+    @patch("matplotlib.pyplot.show")
+    def test_inventory_plot(self, mock_show):
+        """
+        Test method to create decay plots.
+        """
+
+        inv = Inventory({"C-14": 1.0, "K-40": 2.0})
+        _, ax = inv.plot(105, "ky")
+        self.assertEqual(ax.get_xscale(), "linear")
+        self.assertEqual(ax.get_yscale(), "linear")
+        self.assertEqual(ax.get_xlabel(), "Time (ky)")
+        self.assertEqual(ax.get_ylabel(), "Activity")
+        self.assertEqual(ax.get_xlim(), (-5.25, 110.25))
+        self.assertEqual(ax.get_ylim(), (0.0, 2.1))
+        self.assertEqual(ax.get_legend_handles_labels()[-1], ["K-40", "C-14"])
+
+        _, ax = inv.plot(
+            100,
+            xscale="log",
+            yscale="log",
+            yunits="Bq",
+            sig_fig=320,
+            display=["K40", "C14"],
+        )
+        self.assertEqual(ax.get_xscale(), "log")
+        self.assertEqual(ax.get_yscale(), "log")
+        self.assertEqual(ax.get_xlabel(), "Time (s)")
+        self.assertEqual(ax.get_ylabel(), "Activity (Bq)")
+        self.assertEqual(ax.get_xlim()[0], 0.0707945784384138)
+        self.assertEqual(ax.get_ylim(), (0.1, 2.1))
+        self.assertEqual(ax.get_legend_handles_labels()[-1], ["K-40", "C-14"])
+
+        _, ax = inv.plot(100, "ky", xmin=50, ymin=1.0, ymax=2.5, display="K40")
+        self.assertEqual(ax.get_xlim(), (47.5, 102.5))
+        self.assertEqual(ax.get_ylim(), (1.0, 2.5))
+        self.assertEqual(ax.get_legend_handles_labels()[-1], ["K-40"])
+
+        _, ax = inv.plot(100, "ky", order="alphabetical")
+        self.assertEqual(ax.get_legend_handles_labels()[-1], ["C-14", "K-40"])
+
+        with self.assertRaises(ValueError):
+            inv.plot(100, "ky", order="invalid")
+
     def test_inventory___repr__(self):
         """
         Test Inventory representations.
